@@ -1,31 +1,21 @@
-package Opcode;
-
-use 5.006_001;
+package Opcode 1.60;
 
 use strict;
 
-our($VERSION, @ISA, @EXPORT_OK);
-
-$VERSION = "1.56";
-
 use Carp;
 use Exporter 'import';
 use XSLoader;
 
-BEGIN {
-    @EXPORT_OK = qw(
+sub opset (;@);
+sub opset_to_hex ($);
+sub opdump (;$);
+use subs our @EXPORT_OK = qw(
 	opset ops_to_opset
 	opset_to_ops opset_to_hex invert_opset
 	empty_opset full_opset
 	opdesc opcodes opmask define_optag
 	opmask_add verify_opset opdump
-    );
-}
-
-sub opset (;@);
-sub opset_to_hex ($);
-sub opdump (;$);
-use subs @EXPORT_OK;
+);
 
 XSLoader::load();
 
@@ -312,7 +302,7 @@ invert_opset function.
 
     null stub scalar pushmark wantarray const defined undef
 
-    rv2sv sassign
+    rv2sv sassign padsv_store
 
     rv2av aassign aelem aelemfast aelemfast_lex aslice kvaslice
     av2arylen
@@ -353,8 +343,8 @@ invert_opset function.
 
     cmpchain_and cmpchain_dup
 
-    isbool
-    isweak weaken unweaken
+    is_bool
+    is_weak weaken unweaken
 
     leaveeval -- needed for Safe to operate, is safe
 		 without entereval
@@ -451,6 +441,8 @@ These are a hotchpotch of opcodes still waiting to be considered
 
     ceil floor
 
+    is_tainted
+
 =item :base_math
 
 These ops are not included in :base_core because of the risk of them being
